from django.shortcuts import render, redirect
from django.http import JsonResponse
from django.conf import settings
import time
import os
import rust_crud_api # Custom Rust Pyo3 Library 🦀

def create_post_view(request):
    """
    Allow a logged-in user to create a new post.
    If a group is specified in the POST data, the post is associated with that group.
    """
    db_url = settings.DATABASE_URL
    user_id = request.session.get('user_id')
    if not user_id:
        return redirect('login')
    
    context = {}
    if request.method == 'POST':
        content = request.POST.get('content', '').strip()
        # Optionally, get a group_id if the post is for a group:
        group_id = request.POST.get('group_id')
        if group_id:
            try:
                group_id = int(group_id)
            except ValueError:
                group_id = None
        else:
            group_id = None
        
        if not content:
            context['error'] = "Post content cannot be empty."
            return render(request, 'myapp/create_post.html', context)
        
        try:
            rust_crud_api.create_post(db_url, user_id, group_id, content)
            return redirect('feed')
        except Exception as e:
            context['error'] = f"Error creating post: {str(e)}"
    
    return render(request, 'myapp/create_post.html', context)

def feed_view(request):
    """
    Display a global feed of posts.
    """
    db_url = settings.DATABASE_URL
    try:
        posts = rust_crud_api.get_feed(db_url)
    except Exception as e:
        return render(request, 'myapp/feed.html', {'error': str(e)})
    
    return render(request, 'myapp/feed.html', {'posts': posts})